.. _install-obs:


Install for openSUSE and SUSE Linux Enterprise
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This section describes how to install the Networking-Ansible ML2 Driver
for openSUSE Leap 42.1 and SUSE Linux Enterprise Server 12 SP1.

Install components
--------------------------------

#. Install the packages:

   .. code-block:: console

      # zypper --quiet --non-interactive install python2-networking-ansible
